Configuration file helpers and re-exports.
This module keeps the stable perfgate.toml / perfgate.json contract
next to the receipt and schema types it configures.
Re-exports
pub use crate::BaselineServerConfig;pub use crate::BenchConfigFile;pub use crate::ConfigFile;pub use crate::DefaultsConfig;pub use crate::RatchetChange;pub use crate::RatchetConfig;pub use crate::RatchetMode;
Enums
- Config
Load Error - Error returned while loading a perfgate config file.
- Ratchet
Toml Edit Error - Error returned while applying ratchet edits to a TOML config file.
Functions
- apply_
ratchet_ toml_ changes - Apply threshold ratchet changes to a bench section in TOML while preserving comments/order.
- load_
config_ file - Loads a
perfgate.tomlorperfgate.jsonconfig file. - preview_
ratchet_ toml_ changes - Preview ratchet edits as human-readable lines.