pub enum RatchetTomlEditError {
Read {
path: String,
source: Error,
},
Parse {
path: String,
source: TomlError,
},
Malformed(String),
Write {
path: String,
source: Error,
},
}Expand description
Error returned while applying ratchet edits to a TOML config file.
Variants
Read
The config file could not be read.
Parse
The config file could not be parsed as editable TOML.
Malformed(String)
The target TOML structure was malformed.
Write
The updated config file could not be written.