pub struct AggregateReceipt {Show 13 fields
pub schema: String,
pub tool: ToolInfo,
pub run: RunMeta,
pub benchmark: String,
pub policy: AggregationPolicy,
pub quorum: Option<f64>,
pub fail_if: Option<FailIfNOfM>,
pub weight_mode: AggregateWeightMode,
pub weights: BTreeMap<String, f64>,
pub variance_floor: Option<f64>,
pub inputs: Vec<AggregateInput>,
pub verdict: AggregateVerdict,
pub warnings: Vec<String>,
}Fields
schema: Stringtool: ToolInforun: RunMetabenchmark: Stringpolicy: AggregationPolicyquorum: Option<f64>fail_if: Option<FailIfNOfM>weight_mode: AggregateWeightModeweights: BTreeMap<String, f64>variance_floor: Option<f64>inputs: Vec<AggregateInput>verdict: AggregateVerdictwarnings: Vec<String>Trait Implementations
Sourceimpl Clone for AggregateReceipt
impl Clone for AggregateReceipt
Sourcefn clone(&self) -> AggregateReceipt
fn clone(&self) -> AggregateReceipt
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AggregateReceipt
impl Debug for AggregateReceipt
Sourceimpl<'de> Deserialize<'de> for AggregateReceipt
impl<'de> Deserialize<'de> for AggregateReceipt
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AggregateReceipt
impl JsonSchema for AggregateReceipt
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AggregateReceipt
impl PartialEq for AggregateReceipt
Sourcefn eq(&self, other: &AggregateReceipt) -> bool
fn eq(&self, other: &AggregateReceipt) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for AggregateReceipt
impl Serialize for AggregateReceipt
impl StructuralPartialEq for AggregateReceipt