pub struct AggregateVerdict {
pub status: MetricStatus,
pub passed: u32,
pub failed: u32,
pub total: u32,
pub weighted_pass: Option<f64>,
pub weighted_total: Option<f64>,
pub required: Option<f64>,
pub outlier_runners: Option<u32>,
pub reasons: Vec<String>,
}Fields
status: MetricStatuspassed: u32failed: u32total: u32weighted_pass: Option<f64>Weighted pass sum (when using weighted policies).
weighted_total: Option<f64>Weighted total sum (when using weighted policies).
required: Option<f64>Quorum threshold used by quorum/weighted policies.
outlier_runners: Option<u32>Number of runners flagged as variance outliers.
reasons: Vec<String>Trait Implementations
Sourceimpl Clone for AggregateVerdict
impl Clone for AggregateVerdict
Sourcefn clone(&self) -> AggregateVerdict
fn clone(&self) -> AggregateVerdict
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AggregateVerdict
impl Debug for AggregateVerdict
Sourceimpl<'de> Deserialize<'de> for AggregateVerdict
impl<'de> Deserialize<'de> for AggregateVerdict
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AggregateVerdict
impl JsonSchema for AggregateVerdict
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AggregateVerdict
impl PartialEq for AggregateVerdict
Sourcefn eq(&self, other: &AggregateVerdict) -> bool
fn eq(&self, other: &AggregateVerdict) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for AggregateVerdict
impl Serialize for AggregateVerdict
impl StructuralPartialEq for AggregateVerdict