pub struct BenchConfigFile {
pub name: String,
pub cwd: Option<String>,
pub work: Option<u64>,
pub timeout: Option<String>,
pub command: Vec<String>,
pub repeat: Option<u32>,
pub warmup: Option<u32>,
pub metrics: Option<Vec<Metric>>,
pub budgets: Option<BTreeMap<Metric, BudgetOverride>>,
}Fields
name: Stringcwd: Option<String>work: Option<u64>timeout: Option<String>Duration string parseable by humantime, e.g. “2s”.
command: Vec<String>argv vector (no shell parsing).
repeat: Option<u32>Number of measured samples (overrides defaults.repeat).
warmup: Option<u32>Warmup samples excluded from stats (overrides defaults.warmup).
metrics: Option<Vec<Metric>>budgets: Option<BTreeMap<Metric, BudgetOverride>>Trait Implementations
Sourceimpl Clone for BenchConfigFile
impl Clone for BenchConfigFile
Sourcefn clone(&self) -> BenchConfigFile
fn clone(&self) -> BenchConfigFile
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BenchConfigFile
impl Debug for BenchConfigFile
Sourceimpl<'de> Deserialize<'de> for BenchConfigFile
impl<'de> Deserialize<'de> for BenchConfigFile
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BenchConfigFile
impl JsonSchema for BenchConfigFile
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BenchConfigFile
impl PartialEq for BenchConfigFile
Sourceimpl Serialize for BenchConfigFile
impl Serialize for BenchConfigFile
impl StructuralPartialEq for BenchConfigFile