pub struct BenchMeta {
pub name: String,
pub cwd: Option<String>,
pub command: Vec<String>,
pub repeat: u32,
pub warmup: u32,
pub work_units: Option<u64>,
pub timeout_ms: Option<u64>,
}Fields
name: Stringcwd: Option<String>Optional working directory (stringified path).
command: Vec<String>argv vector (no shell parsing).
repeat: u32warmup: u32work_units: Option<u64>timeout_ms: Option<u64>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for BenchMeta
impl<'de> Deserialize<'de> for BenchMeta
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BenchMeta
impl JsonSchema for BenchMeta
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl Eq for BenchMeta
impl StructuralPartialEq for BenchMeta