pub struct Capability {
pub status: CapabilityStatus,
pub reason: Option<String>,
}Expand description
A capability with its status and optional reason.
Fields
status: CapabilityStatusreason: Option<String>Trait Implementations
Sourceimpl Clone for Capability
impl Clone for Capability
Sourcefn clone(&self) -> Capability
fn clone(&self) -> Capability
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Capability
impl Debug for Capability
Sourceimpl<'de> Deserialize<'de> for Capability
impl<'de> Deserialize<'de> for Capability
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Capability
impl JsonSchema for Capability
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for Capability
impl PartialEq for Capability
Sourceimpl Serialize for Capability
impl Serialize for Capability
impl Eq for Capability
impl StructuralPartialEq for Capability