pub struct ChangedFilesSummary {
pub file_count: u32,
pub files: Vec<String>,
pub file_count_by_top_level: BTreeMap<String, u32>,
}Fields
file_count: u32files: Vec<String>file_count_by_top_level: BTreeMap<String, u32>Trait Implementations
Sourceimpl Clone for ChangedFilesSummary
impl Clone for ChangedFilesSummary
Sourcefn clone(&self) -> ChangedFilesSummary
fn clone(&self) -> ChangedFilesSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChangedFilesSummary
impl Debug for ChangedFilesSummary
Sourceimpl<'de> Deserialize<'de> for ChangedFilesSummary
impl<'de> Deserialize<'de> for ChangedFilesSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ChangedFilesSummary
impl JsonSchema for ChangedFilesSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ChangedFilesSummary
impl PartialEq for ChangedFilesSummary
Sourcefn eq(&self, other: &ChangedFilesSummary) -> bool
fn eq(&self, other: &ChangedFilesSummary) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ChangedFilesSummary
impl Serialize for ChangedFilesSummary
impl Eq for ChangedFilesSummary
impl StructuralPartialEq for ChangedFilesSummary