pub struct CompareRef {
pub path: Option<String>,
pub run_id: Option<String>,
}Fields
path: Option<String>run_id: Option<String>Trait Implementations
Sourceimpl Clone for CompareRef
impl Clone for CompareRef
Sourcefn clone(&self) -> CompareRef
fn clone(&self) -> CompareRef
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CompareRef
impl Debug for CompareRef
Sourceimpl<'de> Deserialize<'de> for CompareRef
impl<'de> Deserialize<'de> for CompareRef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CompareRef
impl JsonSchema for CompareRef
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CompareRef
impl PartialEq for CompareRef
Sourceimpl Serialize for CompareRef
impl Serialize for CompareRef
impl Eq for CompareRef
impl StructuralPartialEq for CompareRef