pub struct ComplexityGateResult {
pub status: ComplexityGateStatus,
pub reason: Option<String>,
pub expected: Option<String>,
pub observed: Option<String>,
pub r_squared: Option<f64>,
pub r_squared_threshold: f64,
pub message: String,
}Expand description
Optional complexity-gating result attached to reports.
Fields
status: ComplexityGateStatusreason: Option<String>expected: Option<String>observed: Option<String>r_squared: Option<f64>r_squared_threshold: f64message: StringTrait Implementations
Sourceimpl Clone for ComplexityGateResult
impl Clone for ComplexityGateResult
Sourcefn clone(&self) -> ComplexityGateResult
fn clone(&self) -> ComplexityGateResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ComplexityGateResult
impl Debug for ComplexityGateResult
Sourceimpl<'de> Deserialize<'de> for ComplexityGateResult
impl<'de> Deserialize<'de> for ComplexityGateResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ComplexityGateResult
impl JsonSchema for ComplexityGateResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ComplexityGateResult
impl PartialEq for ComplexityGateResult
Sourcefn eq(&self, other: &ComplexityGateResult) -> bool
fn eq(&self, other: &ComplexityGateResult) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ComplexityGateResult
impl Serialize for ComplexityGateResult
impl StructuralPartialEq for ComplexityGateResult