pub struct ConfigFile {
pub defaults: DefaultsConfig,
pub baseline_server: BaselineServerConfig,
pub decision_policy: DecisionPolicyConfig,
pub ratchet: Option<RatchetConfig>,
pub benches: Vec<BenchConfigFile>,
pub scenarios: Vec<ScenarioConfigFile>,
pub tradeoffs: Vec<TradeoffRule>,
}Expand description
Top-level configuration file (perfgate.toml).
Examples
use perfgate_types::ConfigFile;
let toml_str = r#"
[defaults]
repeat = 5
threshold = 0.20
[[bench]]
name = "my-bench"
command = ["echo", "hello"]
"#;
let config: ConfigFile = toml::from_str(toml_str).unwrap();
assert_eq!(config.benches.len(), 1);
assert_eq!(config.benches[0].name, "my-bench");
assert_eq!(config.defaults.repeat, Some(5));Fields
defaults: DefaultsConfigbaseline_server: BaselineServerConfigOptional baseline server configuration for centralized baseline management.
decision_policy: DecisionPolicyConfigOptional policy for deciding whether tradeoff evidence is stable enough for automatic acceptance.
ratchet: Option<RatchetConfig>Optional automated budget ratcheting policy.
benches: Vec<BenchConfigFile>scenarios: Vec<ScenarioConfigFile>Optional weighted workload scenarios evaluated from compare receipts.
tradeoffs: Vec<TradeoffRule>Optional tradeoff rules that can downgrade a failed metric when explicit compensating improvements are present.
Implementations
Sourceimpl ConfigFile
impl ConfigFile
Sourcepub fn validate(&self) -> Result<(), String>
pub fn validate(&self) -> Result<(), String>
Validate all bench names in this config. Returns an error if any name is invalid.
Examples
use perfgate_types::ConfigFile;
let good: ConfigFile = toml::from_str(r#"
[[bench]]
name = "valid-bench"
command = ["echo"]
"#).unwrap();
assert!(good.validate().is_ok());
let bad: ConfigFile = toml::from_str(r#"
[[bench]]
name = "INVALID|name"
command = ["echo"]
"#).unwrap();
assert!(bad.validate().is_err());Trait Implementations
Sourceimpl Clone for ConfigFile
impl Clone for ConfigFile
Sourcefn clone(&self) -> ConfigFile
fn clone(&self) -> ConfigFile
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConfigFile
impl Debug for ConfigFile
Sourceimpl Default for ConfigFile
impl Default for ConfigFile
Sourcefn default() -> ConfigFile
fn default() -> ConfigFile
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ConfigFile
impl<'de> Deserialize<'de> for ConfigFile
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ConfigFile
impl JsonSchema for ConfigFile
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ConfigFile
impl PartialEq for ConfigFile
Sourcefn eq(&self, other: &ConfigFile) -> bool
fn eq(&self, other: &ConfigFile) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ConfigFile
impl Serialize for ConfigFile
impl StructuralPartialEq for ConfigFile