pub struct DecisionArtifactIndex {
pub schema: String,
pub scenario: String,
pub tradeoff: String,
pub decision: String,
pub probe_compares: Vec<String>,
pub compare_receipts: Vec<String>,
}Expand description
A manifest for the artifacts produced by perfgate decision evaluate.
Fields
schema: Stringscenario: Stringtradeoff: Stringdecision: Stringprobe_compares: Vec<String>compare_receipts: Vec<String>Trait Implementations
Sourceimpl Clone for DecisionArtifactIndex
impl Clone for DecisionArtifactIndex
Sourcefn clone(&self) -> DecisionArtifactIndex
fn clone(&self) -> DecisionArtifactIndex
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DecisionArtifactIndex
impl Debug for DecisionArtifactIndex
Sourceimpl<'de> Deserialize<'de> for DecisionArtifactIndex
impl<'de> Deserialize<'de> for DecisionArtifactIndex
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DecisionArtifactIndex
impl JsonSchema for DecisionArtifactIndex
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DecisionArtifactIndex
impl PartialEq for DecisionArtifactIndex
Sourcefn eq(&self, other: &DecisionArtifactIndex) -> bool
fn eq(&self, other: &DecisionArtifactIndex) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DecisionArtifactIndex
impl Serialize for DecisionArtifactIndex
impl Eq for DecisionArtifactIndex
impl StructuralPartialEq for DecisionArtifactIndex