pub struct DecisionBundleArtifact {
pub path: String,
pub kind: DecisionBundleArtifactKind,
pub media_type: String,
pub sha256: String,
pub schema: Option<String>,
pub content: DecisionBundleArtifactContent,
}Expand description
One artifact embedded in a portable decision bundle.
Fields
path: Stringkind: DecisionBundleArtifactKindmedia_type: Stringsha256: Stringschema: Option<String>content: DecisionBundleArtifactContentTrait Implementations
Sourceimpl Clone for DecisionBundleArtifact
impl Clone for DecisionBundleArtifact
Sourcefn clone(&self) -> DecisionBundleArtifact
fn clone(&self) -> DecisionBundleArtifact
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DecisionBundleArtifact
impl Debug for DecisionBundleArtifact
Sourceimpl<'de> Deserialize<'de> for DecisionBundleArtifact
impl<'de> Deserialize<'de> for DecisionBundleArtifact
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DecisionBundleArtifact
impl JsonSchema for DecisionBundleArtifact
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DecisionBundleArtifact
impl PartialEq for DecisionBundleArtifact
Sourcefn eq(&self, other: &DecisionBundleArtifact) -> bool
fn eq(&self, other: &DecisionBundleArtifact) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DecisionBundleArtifact
impl Serialize for DecisionBundleArtifact
impl StructuralPartialEq for DecisionBundleArtifact