pub struct DecisionBundleMetadata {
pub index_path: String,
pub git_ref: Option<String>,
pub git_sha: Option<String>,
}Expand description
Metadata captured when exporting a portable decision bundle.
Fields
index_path: Stringgit_ref: Option<String>git_sha: Option<String>Trait Implementations
Sourceimpl Clone for DecisionBundleMetadata
impl Clone for DecisionBundleMetadata
Sourcefn clone(&self) -> DecisionBundleMetadata
fn clone(&self) -> DecisionBundleMetadata
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DecisionBundleMetadata
impl Debug for DecisionBundleMetadata
Sourceimpl<'de> Deserialize<'de> for DecisionBundleMetadata
impl<'de> Deserialize<'de> for DecisionBundleMetadata
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DecisionBundleMetadata
impl JsonSchema for DecisionBundleMetadata
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DecisionBundleMetadata
impl PartialEq for DecisionBundleMetadata
Sourcefn eq(&self, other: &DecisionBundleMetadata) -> bool
fn eq(&self, other: &DecisionBundleMetadata) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DecisionBundleMetadata
impl Serialize for DecisionBundleMetadata
impl Eq for DecisionBundleMetadata
impl StructuralPartialEq for DecisionBundleMetadata