pub struct DecisionBundleReceipt {
pub schema: String,
pub tool: ToolInfo,
pub run: RunMeta,
pub metadata: DecisionBundleMetadata,
pub index: DecisionArtifactIndex,
pub artifacts: Vec<DecisionBundleArtifact>,
}Expand description
A portable receipt bundle for structured performance decisions.
Fields
schema: Stringtool: ToolInforun: RunMetametadata: DecisionBundleMetadataindex: DecisionArtifactIndexartifacts: Vec<DecisionBundleArtifact>Trait Implementations
Sourceimpl Clone for DecisionBundleReceipt
impl Clone for DecisionBundleReceipt
Sourcefn clone(&self) -> DecisionBundleReceipt
fn clone(&self) -> DecisionBundleReceipt
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DecisionBundleReceipt
impl Debug for DecisionBundleReceipt
Sourceimpl<'de> Deserialize<'de> for DecisionBundleReceipt
impl<'de> Deserialize<'de> for DecisionBundleReceipt
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DecisionBundleReceipt
impl JsonSchema for DecisionBundleReceipt
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DecisionBundleReceipt
impl PartialEq for DecisionBundleReceipt
Sourcefn eq(&self, other: &DecisionBundleReceipt) -> bool
fn eq(&self, other: &DecisionBundleReceipt) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DecisionBundleReceipt
impl Serialize for DecisionBundleReceipt
impl StructuralPartialEq for DecisionBundleReceipt