pub struct Delta {
pub baseline: f64,
pub current: f64,
pub ratio: f64,
pub pct: f64,
pub regression: f64,
pub cv: Option<f64>,
pub noise_threshold: Option<f64>,
pub statistic: MetricStatistic,
pub significance: Option<Significance>,
pub status: MetricStatus,
}Fields
baseline: f64current: f64ratio: f64current / baseline
pct: f64(current - baseline) / baseline
regression: f64Positive regression amount, normalized as a fraction.
cv: Option<f64>Coefficient of variation for the current run.
noise_threshold: Option<f64>Noise threshold used for this comparison.
statistic: MetricStatisticsignificance: Option<Significance>status: MetricStatusTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Delta
impl<'de> Deserialize<'de> for Delta
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Delta
impl JsonSchema for Delta
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for Delta