pub struct FailIfNOfM {
pub n: u32,
pub m: Option<u32>,
}Fields
n: u32m: Option<u32>Trait Implementations
Sourceimpl Clone for FailIfNOfM
impl Clone for FailIfNOfM
Sourcefn clone(&self) -> FailIfNOfM
fn clone(&self) -> FailIfNOfM
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FailIfNOfM
impl Debug for FailIfNOfM
Sourceimpl<'de> Deserialize<'de> for FailIfNOfM
impl<'de> Deserialize<'de> for FailIfNOfM
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FailIfNOfM
impl JsonSchema for FailIfNOfM
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for FailIfNOfM
impl PartialEq for FailIfNOfM
Sourcefn eq(&self, other: &FailIfNOfM) -> bool
fn eq(&self, other: &FailIfNOfM) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for FailIfNOfM
impl Serialize for FailIfNOfM
impl Eq for FailIfNOfM
impl StructuralPartialEq for FailIfNOfM