pub struct OtelSpanIdentifiers {
pub trace_id: Option<String>,
pub span_id: Option<String>,
}Fields
trace_id: Option<String>span_id: Option<String>Trait Implementations
Sourceimpl Clone for OtelSpanIdentifiers
impl Clone for OtelSpanIdentifiers
Sourcefn clone(&self) -> OtelSpanIdentifiers
fn clone(&self) -> OtelSpanIdentifiers
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OtelSpanIdentifiers
impl Debug for OtelSpanIdentifiers
Sourceimpl<'de> Deserialize<'de> for OtelSpanIdentifiers
impl<'de> Deserialize<'de> for OtelSpanIdentifiers
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for OtelSpanIdentifiers
impl JsonSchema for OtelSpanIdentifiers
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for OtelSpanIdentifiers
impl PartialEq for OtelSpanIdentifiers
Sourcefn eq(&self, other: &OtelSpanIdentifiers) -> bool
fn eq(&self, other: &OtelSpanIdentifiers) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for OtelSpanIdentifiers
impl Serialize for OtelSpanIdentifiers
impl Eq for OtelSpanIdentifiers
impl StructuralPartialEq for OtelSpanIdentifiers