pub struct PairedBenchMeta {
pub name: String,
pub cwd: Option<String>,
pub baseline_command: Vec<String>,
pub current_command: Vec<String>,
pub repeat: u32,
pub warmup: u32,
pub work_units: Option<u64>,
pub timeout_ms: Option<u64>,
}Fields
name: Stringcwd: Option<String>baseline_command: Vec<String>current_command: Vec<String>repeat: u32warmup: u32work_units: Option<u64>timeout_ms: Option<u64>Trait Implementations
Sourceimpl Clone for PairedBenchMeta
impl Clone for PairedBenchMeta
Sourcefn clone(&self) -> PairedBenchMeta
fn clone(&self) -> PairedBenchMeta
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PairedBenchMeta
impl Debug for PairedBenchMeta
Sourceimpl<'de> Deserialize<'de> for PairedBenchMeta
impl<'de> Deserialize<'de> for PairedBenchMeta
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PairedBenchMeta
impl JsonSchema for PairedBenchMeta
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PairedBenchMeta
impl PartialEq for PairedBenchMeta
Sourceimpl Serialize for PairedBenchMeta
impl Serialize for PairedBenchMeta
impl Eq for PairedBenchMeta
impl StructuralPartialEq for PairedBenchMeta