pub struct PairedDiffSummary {
pub mean: f64,
pub median: f64,
pub std_dev: f64,
pub min: f64,
pub max: f64,
pub count: u32,
pub significance: Option<Significance>,
}Fields
mean: f64median: f64std_dev: f64min: f64max: f64count: u32significance: Option<Significance>Trait Implementations
Sourceimpl Clone for PairedDiffSummary
impl Clone for PairedDiffSummary
Sourcefn clone(&self) -> PairedDiffSummary
fn clone(&self) -> PairedDiffSummary
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PairedDiffSummary
impl Debug for PairedDiffSummary
Sourceimpl<'de> Deserialize<'de> for PairedDiffSummary
impl<'de> Deserialize<'de> for PairedDiffSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PairedDiffSummary
impl JsonSchema for PairedDiffSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PairedDiffSummary
impl PartialEq for PairedDiffSummary
Sourceimpl Serialize for PairedDiffSummary
impl Serialize for PairedDiffSummary
impl StructuralPartialEq for PairedDiffSummary