pub struct PairedSample {
pub pair_index: u32,
pub warmup: bool,
pub baseline: PairedSampleHalf,
pub current: PairedSampleHalf,
pub wall_diff_ms: i64,
pub rss_diff_kb: Option<i64>,
}Fields
pair_index: u32warmup: boolbaseline: PairedSampleHalfcurrent: PairedSampleHalfwall_diff_ms: i64rss_diff_kb: Option<i64>Trait Implementations
Sourceimpl Clone for PairedSample
impl Clone for PairedSample
Sourcefn clone(&self) -> PairedSample
fn clone(&self) -> PairedSample
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PairedSample
impl Debug for PairedSample
Sourceimpl<'de> Deserialize<'de> for PairedSample
impl<'de> Deserialize<'de> for PairedSample
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PairedSample
impl JsonSchema for PairedSample
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PairedSample
impl PartialEq for PairedSample
Sourceimpl Serialize for PairedSample
impl Serialize for PairedSample
impl StructuralPartialEq for PairedSample