pub struct PairedSampleHalf {
pub wall_ms: u64,
pub exit_code: i32,
pub timed_out: bool,
pub max_rss_kb: Option<u64>,
pub stdout: Option<String>,
pub stderr: Option<String>,
}Fields
wall_ms: u64exit_code: i32timed_out: boolmax_rss_kb: Option<u64>stdout: Option<String>stderr: Option<String>Trait Implementations
Sourceimpl Clone for PairedSampleHalf
impl Clone for PairedSampleHalf
Sourcefn clone(&self) -> PairedSampleHalf
fn clone(&self) -> PairedSampleHalf
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PairedSampleHalf
impl Debug for PairedSampleHalf
Sourceimpl<'de> Deserialize<'de> for PairedSampleHalf
impl<'de> Deserialize<'de> for PairedSampleHalf
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PairedSampleHalf
impl JsonSchema for PairedSampleHalf
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PairedSampleHalf
impl PartialEq for PairedSampleHalf
Sourceimpl Serialize for PairedSampleHalf
impl Serialize for PairedSampleHalf
impl StructuralPartialEq for PairedSampleHalf