pub struct PairedStats {
pub baseline_wall_ms: U64Summary,
pub current_wall_ms: U64Summary,
pub wall_diff_ms: PairedDiffSummary,
pub baseline_max_rss_kb: Option<U64Summary>,
pub current_max_rss_kb: Option<U64Summary>,
pub rss_diff_kb: Option<PairedDiffSummary>,
pub baseline_throughput_per_s: Option<F64Summary>,
pub current_throughput_per_s: Option<F64Summary>,
pub throughput_diff_per_s: Option<PairedDiffSummary>,
}Fields
baseline_wall_ms: U64Summarycurrent_wall_ms: U64Summarywall_diff_ms: PairedDiffSummarybaseline_max_rss_kb: Option<U64Summary>current_max_rss_kb: Option<U64Summary>rss_diff_kb: Option<PairedDiffSummary>baseline_throughput_per_s: Option<F64Summary>current_throughput_per_s: Option<F64Summary>throughput_diff_per_s: Option<PairedDiffSummary>Trait Implementations
Sourceimpl Clone for PairedStats
impl Clone for PairedStats
Sourcefn clone(&self) -> PairedStats
fn clone(&self) -> PairedStats
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PairedStats
impl Debug for PairedStats
Sourceimpl<'de> Deserialize<'de> for PairedStats
impl<'de> Deserialize<'de> for PairedStats
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PairedStats
impl JsonSchema for PairedStats
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PairedStats
impl PartialEq for PairedStats
Sourceimpl Serialize for PairedStats
impl Serialize for PairedStats
impl StructuralPartialEq for PairedStats