pub struct ProbeCompareObservation {
pub name: String,
pub parent: Option<String>,
pub scope: Option<ProbeScope>,
pub baseline_count: u32,
pub current_count: u32,
pub deltas: BTreeMap<String, Delta>,
pub status: MetricStatus,
pub reasons: Vec<String>,
}Expand description
Comparison evidence for one named probe.
Fields
name: Stringparent: Option<String>scope: Option<ProbeScope>baseline_count: u32current_count: u32deltas: BTreeMap<String, Delta>status: MetricStatusreasons: Vec<String>Trait Implementations
Sourceimpl Clone for ProbeCompareObservation
impl Clone for ProbeCompareObservation
Sourcefn clone(&self) -> ProbeCompareObservation
fn clone(&self) -> ProbeCompareObservation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProbeCompareObservation
impl Debug for ProbeCompareObservation
Sourceimpl<'de> Deserialize<'de> for ProbeCompareObservation
impl<'de> Deserialize<'de> for ProbeCompareObservation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProbeCompareObservation
impl JsonSchema for ProbeCompareObservation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProbeCompareObservation
impl PartialEq for ProbeCompareObservation
Sourcefn eq(&self, other: &ProbeCompareObservation) -> bool
fn eq(&self, other: &ProbeCompareObservation) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ProbeCompareObservation
impl Serialize for ProbeCompareObservation
impl StructuralPartialEq for ProbeCompareObservation