pub struct ProbeCompareReceipt {
pub schema: String,
pub tool: ToolInfo,
pub run: RunMeta,
pub bench: Option<BenchMeta>,
pub scenario: Option<String>,
pub baseline_ref: Option<CompareRef>,
pub current_ref: Option<CompareRef>,
pub probes: Vec<ProbeCompareObservation>,
pub verdict: Verdict,
pub warnings: Vec<String>,
}Expand description
A versioned receipt for named probe deltas (perfgate.probe_compare.v1).
Fields
schema: Stringtool: ToolInforun: RunMetabench: Option<BenchMeta>scenario: Option<String>baseline_ref: Option<CompareRef>current_ref: Option<CompareRef>probes: Vec<ProbeCompareObservation>verdict: Verdictwarnings: Vec<String>Trait Implementations
Sourceimpl Clone for ProbeCompareReceipt
impl Clone for ProbeCompareReceipt
Sourcefn clone(&self) -> ProbeCompareReceipt
fn clone(&self) -> ProbeCompareReceipt
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProbeCompareReceipt
impl Debug for ProbeCompareReceipt
Sourceimpl<'de> Deserialize<'de> for ProbeCompareReceipt
impl<'de> Deserialize<'de> for ProbeCompareReceipt
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProbeCompareReceipt
impl JsonSchema for ProbeCompareReceipt
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProbeCompareReceipt
impl PartialEq for ProbeCompareReceipt
Sourcefn eq(&self, other: &ProbeCompareReceipt) -> bool
fn eq(&self, other: &ProbeCompareReceipt) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ProbeCompareReceipt
impl Serialize for ProbeCompareReceipt
impl StructuralPartialEq for ProbeCompareReceipt