pub struct ProbeMetricValue {
pub value: f64,
pub unit: Option<String>,
pub statistic: Option<String>,
}Expand description
A numeric metric observed for a named probe.
Fields
value: f64unit: Option<String>statistic: Option<String>Trait Implementations
Sourceimpl Clone for ProbeMetricValue
impl Clone for ProbeMetricValue
Sourcefn clone(&self) -> ProbeMetricValue
fn clone(&self) -> ProbeMetricValue
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProbeMetricValue
impl Debug for ProbeMetricValue
Sourceimpl<'de> Deserialize<'de> for ProbeMetricValue
impl<'de> Deserialize<'de> for ProbeMetricValue
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProbeMetricValue
impl JsonSchema for ProbeMetricValue
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProbeMetricValue
impl PartialEq for ProbeMetricValue
Sourcefn eq(&self, other: &ProbeMetricValue) -> bool
fn eq(&self, other: &ProbeMetricValue) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ProbeMetricValue
impl Serialize for ProbeMetricValue
impl StructuralPartialEq for ProbeMetricValue