pub struct ProbeObservation {
pub name: String,
pub parent: Option<String>,
pub scope: Option<ProbeScope>,
pub iteration: Option<u32>,
pub started_at: Option<String>,
pub ended_at: Option<String>,
pub items: Option<u64>,
pub metrics: BTreeMap<String, ProbeMetricValue>,
pub attributes: BTreeMap<String, String>,
}Expand description
One named probe observation from external instrumentation.
Fields
name: Stringparent: Option<String>scope: Option<ProbeScope>iteration: Option<u32>started_at: Option<String>ended_at: Option<String>items: Option<u64>metrics: BTreeMap<String, ProbeMetricValue>attributes: BTreeMap<String, String>Trait Implementations
Sourceimpl Clone for ProbeObservation
impl Clone for ProbeObservation
Sourcefn clone(&self) -> ProbeObservation
fn clone(&self) -> ProbeObservation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProbeObservation
impl Debug for ProbeObservation
Sourceimpl<'de> Deserialize<'de> for ProbeObservation
impl<'de> Deserialize<'de> for ProbeObservation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProbeObservation
impl JsonSchema for ProbeObservation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProbeObservation
impl PartialEq for ProbeObservation
Sourcefn eq(&self, other: &ProbeObservation) -> bool
fn eq(&self, other: &ProbeObservation) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ProbeObservation
impl Serialize for ProbeObservation
impl StructuralPartialEq for ProbeObservation