pub struct ProbeReceipt {
pub schema: String,
pub tool: ToolInfo,
pub run: RunMeta,
pub bench: Option<BenchMeta>,
pub scenario: Option<String>,
pub probes: Vec<ProbeObservation>,
pub metadata: BTreeMap<String, String>,
}Expand description
A versioned receipt for named probe observations (perfgate.probe.v1).
Fields
schema: Stringtool: ToolInforun: RunMetabench: Option<BenchMeta>scenario: Option<String>probes: Vec<ProbeObservation>metadata: BTreeMap<String, String>Trait Implementations
Sourceimpl Clone for ProbeReceipt
impl Clone for ProbeReceipt
Sourcefn clone(&self) -> ProbeReceipt
fn clone(&self) -> ProbeReceipt
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProbeReceipt
impl Debug for ProbeReceipt
Sourceimpl<'de> Deserialize<'de> for ProbeReceipt
impl<'de> Deserialize<'de> for ProbeReceipt
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProbeReceipt
impl JsonSchema for ProbeReceipt
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProbeReceipt
impl PartialEq for ProbeReceipt
Sourcefn eq(&self, other: &ProbeReceipt) -> bool
fn eq(&self, other: &ProbeReceipt) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ProbeReceipt
impl Serialize for ProbeReceipt
impl StructuralPartialEq for ProbeReceipt