pub struct RatchetChange {
pub metric: Metric,
pub field: String,
pub old_value: f64,
pub new_value: f64,
pub reason: String,
}Expand description
Per-metric ratchet change.
Fields
metric: Metricfield: Stringold_value: f64new_value: f64reason: StringTrait Implementations
Sourceimpl Clone for RatchetChange
impl Clone for RatchetChange
Sourcefn clone(&self) -> RatchetChange
fn clone(&self) -> RatchetChange
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RatchetChange
impl Debug for RatchetChange
Sourceimpl<'de> Deserialize<'de> for RatchetChange
impl<'de> Deserialize<'de> for RatchetChange
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RatchetChange
impl JsonSchema for RatchetChange
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RatchetChange
impl PartialEq for RatchetChange
Sourcefn eq(&self, other: &RatchetChange) -> bool
fn eq(&self, other: &RatchetChange) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RatchetChange
impl Serialize for RatchetChange
impl StructuralPartialEq for RatchetChange