pub struct RatchetConfig {
pub enabled: bool,
pub mode: RatchetMode,
pub min_improvement: f64,
pub max_tightening: f64,
pub require_significance: bool,
pub allow_metrics: Vec<Metric>,
}Expand description
Configuration for conservative automated budget ratcheting.
Fields
enabled: boolmode: RatchetModemin_improvement: f64max_tightening: f64require_significance: boolallow_metrics: Vec<Metric>Trait Implementations
Sourceimpl Clone for RatchetConfig
impl Clone for RatchetConfig
Sourcefn clone(&self) -> RatchetConfig
fn clone(&self) -> RatchetConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RatchetConfig
impl Debug for RatchetConfig
Sourceimpl Default for RatchetConfig
impl Default for RatchetConfig
Sourceimpl<'de> Deserialize<'de> for RatchetConfig
impl<'de> Deserialize<'de> for RatchetConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RatchetConfig
impl JsonSchema for RatchetConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RatchetConfig
impl PartialEq for RatchetConfig
Sourcefn eq(&self, other: &RatchetConfig) -> bool
fn eq(&self, other: &RatchetConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RatchetConfig
impl Serialize for RatchetConfig
impl StructuralPartialEq for RatchetConfig