pub struct RatchetReceipt {
pub schema: String,
pub tool: ToolInfo,
pub bench_name: String,
pub compare_path: Option<String>,
pub changes: Vec<RatchetChange>,
}Expand description
Machine-readable ratchet artifact.
Fields
schema: Stringtool: ToolInfobench_name: Stringcompare_path: Option<String>changes: Vec<RatchetChange>Trait Implementations
Sourceimpl Clone for RatchetReceipt
impl Clone for RatchetReceipt
Sourcefn clone(&self) -> RatchetReceipt
fn clone(&self) -> RatchetReceipt
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RatchetReceipt
impl Debug for RatchetReceipt
Sourceimpl<'de> Deserialize<'de> for RatchetReceipt
impl<'de> Deserialize<'de> for RatchetReceipt
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RatchetReceipt
impl JsonSchema for RatchetReceipt
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RatchetReceipt
impl PartialEq for RatchetReceipt
Sourcefn eq(&self, other: &RatchetReceipt) -> bool
fn eq(&self, other: &RatchetReceipt) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RatchetReceipt
impl Serialize for RatchetReceipt
impl StructuralPartialEq for RatchetReceipt