pub struct RepairMetricBreach {
pub metric: Metric,
pub status: String,
pub baseline: f64,
pub current: f64,
pub regression: f64,
pub fail_threshold: f64,
pub warn_threshold: f64,
}Fields
metric: Metricstatus: Stringbaseline: f64current: f64regression: f64fail_threshold: f64warn_threshold: f64Trait Implementations
Sourceimpl Clone for RepairMetricBreach
impl Clone for RepairMetricBreach
Sourcefn clone(&self) -> RepairMetricBreach
fn clone(&self) -> RepairMetricBreach
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RepairMetricBreach
impl Debug for RepairMetricBreach
Sourceimpl<'de> Deserialize<'de> for RepairMetricBreach
impl<'de> Deserialize<'de> for RepairMetricBreach
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RepairMetricBreach
impl JsonSchema for RepairMetricBreach
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RepairMetricBreach
impl PartialEq for RepairMetricBreach
Sourcefn eq(&self, other: &RepairMetricBreach) -> bool
fn eq(&self, other: &RepairMetricBreach) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RepairMetricBreach
impl Serialize for RepairMetricBreach
impl StructuralPartialEq for RepairMetricBreach