pub struct RunMeta {
pub id: String,
pub started_at: String,
pub ended_at: String,
pub host: HostInfo,
}Fields
id: Stringstarted_at: Stringended_at: Stringhost: HostInfoTrait Implementations
Sourceimpl<'de> Deserialize<'de> for RunMeta
impl<'de> Deserialize<'de> for RunMeta
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RunMeta
impl JsonSchema for RunMeta
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl Eq for RunMeta
impl StructuralPartialEq for RunMeta