pub struct ScenarioComponent {
pub name: String,
pub weight: f64,
pub benchmark: Option<String>,
pub compare_ref: Option<CompareRef>,
pub probe_compare_ref: Option<CompareRef>,
pub deltas: BTreeMap<String, Delta>,
pub probes: Vec<String>,
pub status: MetricStatus,
pub reasons: Vec<String>,
}Expand description
A scenario component such as one benchmark, phase, or probe group.
Fields
name: Stringweight: f64benchmark: Option<String>compare_ref: Option<CompareRef>probe_compare_ref: Option<CompareRef>deltas: BTreeMap<String, Delta>probes: Vec<String>status: MetricStatusreasons: Vec<String>Trait Implementations
Sourceimpl Clone for ScenarioComponent
impl Clone for ScenarioComponent
Sourcefn clone(&self) -> ScenarioComponent
fn clone(&self) -> ScenarioComponent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScenarioComponent
impl Debug for ScenarioComponent
Sourceimpl<'de> Deserialize<'de> for ScenarioComponent
impl<'de> Deserialize<'de> for ScenarioComponent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ScenarioComponent
impl JsonSchema for ScenarioComponent
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ScenarioComponent
impl PartialEq for ScenarioComponent
Sourcefn eq(&self, other: &ScenarioComponent) -> bool
fn eq(&self, other: &ScenarioComponent) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ScenarioComponent
impl Serialize for ScenarioComponent
impl StructuralPartialEq for ScenarioComponent