pub struct ScenarioMeta {
pub name: String,
pub weight: f64,
pub description: Option<String>,
pub command: Option<Vec<String>>,
}Expand description
Scenario definition captured in a scenario evaluation receipt.
Fields
name: Stringweight: f64description: Option<String>command: Option<Vec<String>>Trait Implementations
Sourceimpl Clone for ScenarioMeta
impl Clone for ScenarioMeta
Sourcefn clone(&self) -> ScenarioMeta
fn clone(&self) -> ScenarioMeta
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScenarioMeta
impl Debug for ScenarioMeta
Sourceimpl<'de> Deserialize<'de> for ScenarioMeta
impl<'de> Deserialize<'de> for ScenarioMeta
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ScenarioMeta
impl JsonSchema for ScenarioMeta
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ScenarioMeta
impl PartialEq for ScenarioMeta
Sourcefn eq(&self, other: &ScenarioMeta) -> bool
fn eq(&self, other: &ScenarioMeta) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ScenarioMeta
impl Serialize for ScenarioMeta
impl StructuralPartialEq for ScenarioMeta