pub struct ScenarioReceipt {
pub schema: String,
pub tool: ToolInfo,
pub run: RunMeta,
pub scenario: ScenarioMeta,
pub baseline_ref: Option<CompareRef>,
pub current_ref: Option<CompareRef>,
pub components: Vec<ScenarioComponent>,
pub weighted_deltas: BTreeMap<String, Delta>,
pub verdict: Verdict,
pub warnings: Vec<String>,
}Expand description
A versioned receipt for weighted workload scenarios (perfgate.scenario.v1).
Fields
schema: Stringtool: ToolInforun: RunMetascenario: ScenarioMetabaseline_ref: Option<CompareRef>current_ref: Option<CompareRef>components: Vec<ScenarioComponent>weighted_deltas: BTreeMap<String, Delta>verdict: Verdictwarnings: Vec<String>Trait Implementations
Sourceimpl Clone for ScenarioReceipt
impl Clone for ScenarioReceipt
Sourcefn clone(&self) -> ScenarioReceipt
fn clone(&self) -> ScenarioReceipt
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScenarioReceipt
impl Debug for ScenarioReceipt
Sourceimpl<'de> Deserialize<'de> for ScenarioReceipt
impl<'de> Deserialize<'de> for ScenarioReceipt
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ScenarioReceipt
impl JsonSchema for ScenarioReceipt
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ScenarioReceipt
impl PartialEq for ScenarioReceipt
Sourcefn eq(&self, other: &ScenarioReceipt) -> bool
fn eq(&self, other: &ScenarioReceipt) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ScenarioReceipt
impl Serialize for ScenarioReceipt
impl StructuralPartialEq for ScenarioReceipt