pub struct SensorArtifact {
pub path: String,
pub artifact_type: String,
}Expand description
An artifact produced by the sensor.
Fields
path: Stringartifact_type: StringTrait Implementations
Sourceimpl Clone for SensorArtifact
impl Clone for SensorArtifact
Sourcefn clone(&self) -> SensorArtifact
fn clone(&self) -> SensorArtifact
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SensorArtifact
impl Debug for SensorArtifact
Sourceimpl<'de> Deserialize<'de> for SensorArtifact
impl<'de> Deserialize<'de> for SensorArtifact
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SensorArtifact
impl JsonSchema for SensorArtifact
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SensorArtifact
impl PartialEq for SensorArtifact
Sourceimpl Serialize for SensorArtifact
impl Serialize for SensorArtifact
impl Eq for SensorArtifact
impl StructuralPartialEq for SensorArtifact