pub struct SensorVerdict {
pub status: SensorVerdictStatus,
pub counts: SensorVerdictCounts,
pub reasons: Vec<String>,
}Expand description
Verdict for the sensor report.
Fields
status: SensorVerdictStatuscounts: SensorVerdictCountsreasons: Vec<String>Trait Implementations
Sourceimpl Clone for SensorVerdict
impl Clone for SensorVerdict
Sourcefn clone(&self) -> SensorVerdict
fn clone(&self) -> SensorVerdict
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SensorVerdict
impl Debug for SensorVerdict
Sourceimpl<'de> Deserialize<'de> for SensorVerdict
impl<'de> Deserialize<'de> for SensorVerdict
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SensorVerdict
impl JsonSchema for SensorVerdict
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SensorVerdict
impl PartialEq for SensorVerdict
Sourceimpl Serialize for SensorVerdict
impl Serialize for SensorVerdict
impl Eq for SensorVerdict
impl StructuralPartialEq for SensorVerdict