pub struct SensorVerdictCounts {
pub info: u32,
pub warn: u32,
pub error: u32,
}Expand description
Verdict counts for the sensor report.
Fields
info: u32warn: u32error: u32Trait Implementations
Sourceimpl Clone for SensorVerdictCounts
impl Clone for SensorVerdictCounts
Sourcefn clone(&self) -> SensorVerdictCounts
fn clone(&self) -> SensorVerdictCounts
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SensorVerdictCounts
impl Debug for SensorVerdictCounts
Sourceimpl<'de> Deserialize<'de> for SensorVerdictCounts
impl<'de> Deserialize<'de> for SensorVerdictCounts
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SensorVerdictCounts
impl JsonSchema for SensorVerdictCounts
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SensorVerdictCounts
impl PartialEq for SensorVerdictCounts
Sourceimpl Serialize for SensorVerdictCounts
impl Serialize for SensorVerdictCounts
impl Eq for SensorVerdictCounts
impl StructuralPartialEq for SensorVerdictCounts