pub struct Significance {
pub test: SignificanceTest,
pub p_value: Option<f64>,
pub alpha: f64,
pub significant: bool,
pub baseline_samples: u32,
pub current_samples: u32,
pub ci_lower: Option<f64>,
pub ci_upper: Option<f64>,
}Fields
test: SignificanceTestp_value: Option<f64>alpha: f64significant: boolbaseline_samples: u32current_samples: u32ci_lower: Option<f64>ci_upper: Option<f64>Trait Implementations
Sourceimpl Clone for Significance
impl Clone for Significance
Sourcefn clone(&self) -> Significance
fn clone(&self) -> Significance
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Significance
impl Debug for Significance
Sourceimpl<'de> Deserialize<'de> for Significance
impl<'de> Deserialize<'de> for Significance
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Significance
impl JsonSchema for Significance
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for Significance
impl PartialEq for Significance
Sourceimpl Serialize for Significance
impl Serialize for Significance
impl StructuralPartialEq for Significance