pub struct TradeoffAllowance {
pub metric: Metric,
pub probe: String,
pub max_regression: f64,
}Expand description
A local regression allowance used by a tradeoff rule.
Fields
metric: MetricMetric whose local regression is capped.
probe: StringProbe name that is allowed to regress within the configured cap.
max_regression: f64Maximum accepted regression as a ratio.
For example, 0.03 allows up to a 3% local regression.