pub struct TradeoffAllowanceOutcome {
pub metric: String,
pub probe: String,
pub max_regression: f64,
pub observed_regression: Option<f64>,
pub satisfied: bool,
pub status: MetricStatus,
pub reason: Option<String>,
}Expand description
Evaluation result for one local regression allowance.
Fields
metric: Stringprobe: Stringmax_regression: f64observed_regression: Option<f64>satisfied: boolstatus: MetricStatusreason: Option<String>Trait Implementations
Sourceimpl Clone for TradeoffAllowanceOutcome
impl Clone for TradeoffAllowanceOutcome
Sourcefn clone(&self) -> TradeoffAllowanceOutcome
fn clone(&self) -> TradeoffAllowanceOutcome
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TradeoffAllowanceOutcome
impl Debug for TradeoffAllowanceOutcome
Sourceimpl<'de> Deserialize<'de> for TradeoffAllowanceOutcome
impl<'de> Deserialize<'de> for TradeoffAllowanceOutcome
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TradeoffAllowanceOutcome
impl JsonSchema for TradeoffAllowanceOutcome
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TradeoffAllowanceOutcome
impl PartialEq for TradeoffAllowanceOutcome
Sourcefn eq(&self, other: &TradeoffAllowanceOutcome) -> bool
fn eq(&self, other: &TradeoffAllowanceOutcome) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for TradeoffAllowanceOutcome
impl Serialize for TradeoffAllowanceOutcome
impl StructuralPartialEq for TradeoffAllowanceOutcome