pub struct TradeoffDecision {
pub accepted_tradeoff: bool,
pub review_required: bool,
pub review_reasons: Vec<String>,
pub status: MetricStatus,
pub reason: String,
}Expand description
Final structured tradeoff decision.
Fields
accepted_tradeoff: boolreview_required: boolreview_reasons: Vec<String>status: MetricStatusreason: StringTrait Implementations
Sourceimpl Clone for TradeoffDecision
impl Clone for TradeoffDecision
Sourcefn clone(&self) -> TradeoffDecision
fn clone(&self) -> TradeoffDecision
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TradeoffDecision
impl Debug for TradeoffDecision
Sourceimpl<'de> Deserialize<'de> for TradeoffDecision
impl<'de> Deserialize<'de> for TradeoffDecision
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TradeoffDecision
impl JsonSchema for TradeoffDecision
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TradeoffDecision
impl PartialEq for TradeoffDecision
Sourcefn eq(&self, other: &TradeoffDecision) -> bool
fn eq(&self, other: &TradeoffDecision) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for TradeoffDecision
impl Serialize for TradeoffDecision
impl StructuralPartialEq for TradeoffDecision