pub struct TradeoffProbeOutcome {
pub name: String,
pub scope: Option<ProbeScope>,
pub weight: Option<f64>,
pub deltas: BTreeMap<String, Delta>,
pub status: MetricStatus,
pub reason: Option<String>,
}Expand description
Probe-level tradeoff evidence.
Fields
name: Stringscope: Option<ProbeScope>weight: Option<f64>deltas: BTreeMap<String, Delta>status: MetricStatusreason: Option<String>Trait Implementations
Sourceimpl Clone for TradeoffProbeOutcome
impl Clone for TradeoffProbeOutcome
Sourcefn clone(&self) -> TradeoffProbeOutcome
fn clone(&self) -> TradeoffProbeOutcome
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TradeoffProbeOutcome
impl Debug for TradeoffProbeOutcome
Sourceimpl<'de> Deserialize<'de> for TradeoffProbeOutcome
impl<'de> Deserialize<'de> for TradeoffProbeOutcome
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TradeoffProbeOutcome
impl JsonSchema for TradeoffProbeOutcome
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TradeoffProbeOutcome
impl PartialEq for TradeoffProbeOutcome
Sourcefn eq(&self, other: &TradeoffProbeOutcome) -> bool
fn eq(&self, other: &TradeoffProbeOutcome) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for TradeoffProbeOutcome
impl Serialize for TradeoffProbeOutcome
impl StructuralPartialEq for TradeoffProbeOutcome