pub struct TradeoffReceipt {Show 13 fields
pub schema: String,
pub tool: ToolInfo,
pub run: RunMeta,
pub scenario: Option<String>,
pub baseline_ref: Option<CompareRef>,
pub current_ref: Option<CompareRef>,
pub configured_rules: Vec<TradeoffRule>,
pub rules: Vec<TradeoffRuleOutcome>,
pub probes: Vec<TradeoffProbeOutcome>,
pub weighted_deltas: BTreeMap<String, Delta>,
pub decision: TradeoffDecision,
pub verdict: Verdict,
pub warnings: Vec<String>,
}Expand description
A versioned receipt explaining accepted or rejected tradeoffs (perfgate.tradeoff.v1).
Fields
schema: Stringtool: ToolInforun: RunMetascenario: Option<String>baseline_ref: Option<CompareRef>current_ref: Option<CompareRef>configured_rules: Vec<TradeoffRule>rules: Vec<TradeoffRuleOutcome>probes: Vec<TradeoffProbeOutcome>weighted_deltas: BTreeMap<String, Delta>decision: TradeoffDecisionverdict: Verdictwarnings: Vec<String>Trait Implementations
Sourceimpl Clone for TradeoffReceipt
impl Clone for TradeoffReceipt
Sourcefn clone(&self) -> TradeoffReceipt
fn clone(&self) -> TradeoffReceipt
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TradeoffReceipt
impl Debug for TradeoffReceipt
Sourceimpl<'de> Deserialize<'de> for TradeoffReceipt
impl<'de> Deserialize<'de> for TradeoffReceipt
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TradeoffReceipt
impl JsonSchema for TradeoffReceipt
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TradeoffReceipt
impl PartialEq for TradeoffReceipt
Sourcefn eq(&self, other: &TradeoffReceipt) -> bool
fn eq(&self, other: &TradeoffReceipt) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for TradeoffReceipt
impl Serialize for TradeoffReceipt
impl StructuralPartialEq for TradeoffReceipt