pub struct TradeoffRequirementOutcome {
pub metric: String,
pub probe: Option<String>,
pub required_change: f64,
pub observed_change: Option<f64>,
pub satisfied: bool,
pub status: MetricStatus,
pub reason: Option<String>,
}Expand description
Evaluation result for one tradeoff requirement.
Fields
metric: Stringprobe: Option<String>required_change: f64observed_change: Option<f64>satisfied: boolstatus: MetricStatusreason: Option<String>Trait Implementations
Sourceimpl Clone for TradeoffRequirementOutcome
impl Clone for TradeoffRequirementOutcome
Sourcefn clone(&self) -> TradeoffRequirementOutcome
fn clone(&self) -> TradeoffRequirementOutcome
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TradeoffRequirementOutcome
impl Debug for TradeoffRequirementOutcome
Sourceimpl<'de> Deserialize<'de> for TradeoffRequirementOutcome
impl<'de> Deserialize<'de> for TradeoffRequirementOutcome
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TradeoffRequirementOutcome
impl JsonSchema for TradeoffRequirementOutcome
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TradeoffRequirementOutcome
impl PartialEq for TradeoffRequirementOutcome
Sourcefn eq(&self, other: &TradeoffRequirementOutcome) -> bool
fn eq(&self, other: &TradeoffRequirementOutcome) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TradeoffRequirementOutcome