pub struct TradeoffRuleOutcome {
pub name: String,
pub status: TradeoffDecisionStatus,
pub accepted: bool,
pub downgrade_to: Option<TradeoffDowngrade>,
pub reason: Option<String>,
pub requirements: Vec<TradeoffRequirementOutcome>,
pub allowances: Vec<TradeoffAllowanceOutcome>,
}Expand description
Evaluation result for one named tradeoff rule.
Fields
name: Stringstatus: TradeoffDecisionStatusaccepted: booldowngrade_to: Option<TradeoffDowngrade>reason: Option<String>requirements: Vec<TradeoffRequirementOutcome>allowances: Vec<TradeoffAllowanceOutcome>Trait Implementations
Sourceimpl Clone for TradeoffRuleOutcome
impl Clone for TradeoffRuleOutcome
Sourcefn clone(&self) -> TradeoffRuleOutcome
fn clone(&self) -> TradeoffRuleOutcome
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TradeoffRuleOutcome
impl Debug for TradeoffRuleOutcome
Sourceimpl<'de> Deserialize<'de> for TradeoffRuleOutcome
impl<'de> Deserialize<'de> for TradeoffRuleOutcome
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TradeoffRuleOutcome
impl JsonSchema for TradeoffRuleOutcome
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TradeoffRuleOutcome
impl PartialEq for TradeoffRuleOutcome
Sourcefn eq(&self, other: &TradeoffRuleOutcome) -> bool
fn eq(&self, other: &TradeoffRuleOutcome) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for TradeoffRuleOutcome
impl Serialize for TradeoffRuleOutcome
impl StructuralPartialEq for TradeoffRuleOutcome