pub struct Verdict {
pub status: VerdictStatus,
pub counts: VerdictCounts,
pub reasons: Vec<String>,
}Expand description
Overall verdict for a comparison, with pass/warn/fail counts.
Examples
use perfgate_types::{Verdict, VerdictStatus, VerdictCounts};
let verdict = Verdict {
status: VerdictStatus::Pass,
counts: VerdictCounts { pass: 2, warn: 0, fail: 0, skip: 0 },
reasons: vec![],
};
assert_eq!(verdict.status, VerdictStatus::Pass);
let failing = Verdict {
status: VerdictStatus::Fail,
counts: VerdictCounts { pass: 1, warn: 0, fail: 1, skip: 0 },
reasons: vec!["wall_ms.fail".into()],
};
assert_eq!(failing.status, VerdictStatus::Fail);
assert!(!failing.reasons.is_empty());Fields
status: VerdictStatuscounts: VerdictCountsreasons: Vec<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Verdict
impl<'de> Deserialize<'de> for Verdict
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Verdict
impl JsonSchema for Verdict
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl Eq for Verdict
impl StructuralPartialEq for Verdict