pub struct VerdictCounts {
pub pass: u32,
pub warn: u32,
pub fail: u32,
pub skip: u32,
}Fields
pass: u32warn: u32fail: u32skip: u32Trait Implementations
Sourceimpl Clone for VerdictCounts
impl Clone for VerdictCounts
Sourcefn clone(&self) -> VerdictCounts
fn clone(&self) -> VerdictCounts
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VerdictCounts
impl Debug for VerdictCounts
Sourceimpl<'de> Deserialize<'de> for VerdictCounts
impl<'de> Deserialize<'de> for VerdictCounts
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for VerdictCounts
impl JsonSchema for VerdictCounts
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for VerdictCounts
impl PartialEq for VerdictCounts
Sourceimpl Serialize for VerdictCounts
impl Serialize for VerdictCounts
impl Eq for VerdictCounts
impl StructuralPartialEq for VerdictCounts