pub struct Stats {
pub wall_ms: U64Summary,
pub cpu_ms: Option<U64Summary>,
pub page_faults: Option<U64Summary>,
pub ctx_switches: Option<U64Summary>,
pub max_rss_kb: Option<U64Summary>,
pub binary_bytes: Option<U64Summary>,
pub throughput_per_s: Option<F64Summary>,
}Expand description
Aggregated statistics for a benchmark run.
Examples
use perfgate_types::{Stats, U64Summary};
let stats = Stats {
wall_ms: U64Summary { median: 100, min: 90, max: 120 },
cpu_ms: None,
page_faults: None,
ctx_switches: None,
max_rss_kb: Some(U64Summary { median: 4096, min: 4000, max: 4200 }),
binary_bytes: None,
throughput_per_s: None,
};
assert_eq!(stats.wall_ms.median, 100);
assert_eq!(stats.max_rss_kb.unwrap().median, 4096);Fields
wall_ms: U64Summarycpu_ms: Option<U64Summary>CPU time (user + system) summary in milliseconds (Unix only).
page_faults: Option<U64Summary>Major page faults summary (Unix only).
ctx_switches: Option<U64Summary>Voluntary + involuntary context switches summary (Unix only).
max_rss_kb: Option<U64Summary>binary_bytes: Option<U64Summary>Size of executed binary in bytes (best-effort).
throughput_per_s: Option<F64Summary>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Stats
impl<'de> Deserialize<'de> for Stats
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Stats
impl JsonSchema for Stats
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for Stats